#  setup.sh
# 
#  Script to run the DB2 OLAP installation.
#
#  If a filename is passed in, then the script will
#  launch the silent install.  Otherwise, the script
#  will launch the install with the user interface.
#

platform=`uname -s`
cd_dir=`pwd`
install_exe=ominer
silent_install_exe=ominer_s
file_name=$1
ucheck=`(ulimit -s)`
min_limit="32000"
let stop_install=0;


case "$platform" in

SunOS)  platform=solaris
		export LD_LIBRARY_PATH=$cd_dir
        
        # Increase the stack size to avoid
        # stack overflow from panel installation.
        
        if [ $ucheck -lt $min_limit ] ; then
           ulimit -s $min_limit
        fi
        
        if [ $ucheck -lt $min_limit ] ; then
           echo 
           echo The user limit on this server is too low to run the OLAP installation.
           echo The installer was not able to update the user limit.  Please add the
           echo following to your profile file and log out and back into the server
           echo to update the user limit setting.
           echo 
           echo ADD TO YOUR PROFILE FILE:
           echo ulimit -s $min_limit 
           let stop_install=1
        fi
        
	;;
HP-UX)   platform=hpux
		export SHLIB_PATH=$SHLIB_PATH:$cd_dir
		export SHLIB_PATH=$SHLIB_PATH:/usr/lib
	;;
AIX)    platform=aix  
		export LIBPATH=$cd_dir
	;;
    
Linux)  platform=SQLLINUX  
	;;


*)      echo Unrecognized platform: "$platform"
        exit 1 ;;
esac

# lib_path=`printenv LIBPATH`
# echo The platform is $platform
# echo The cd_dir is $cd_dir
# echo The executable is $cd_dir/product/$install_exe
# echo The filename is $file_name 
# echo The libpath set is $lib_path
# exit 0



echo Unsetting Java environment variables for this session.
unset JREHOME
unset JAVA_HOME

if [ $stop_install -eq 1 ] ; then
exit 0
fi

if [ -n "$file_name" ]; then

	if [ ! -f $cd_dir/$silent_install_exe ]; then
   		echo The installer cannot find the $cd_dir/$silent_install_exe file
        echo that is needed to run the installation. 
       	exit 1
	fi

	if [ ! -f $file_name ]; then
   		echo The installer cannot find the response file $file_name
    	echo The full path must be included. 
        exit 1
	fi
    
	$cd_dir/$silent_install_exe $file_name

else

	if [ ! -f $cd_dir/$install_exe ]; then
   		echo The installer cannot find the $cd_dir/$install_exe file
        echo that is needed to run the installation. 
       	exit 1
	fi


	$cd_dir/$install_exe
	
fi

exit 0
